====
Pylp
====


What is pylp?
=============

| Pylp is a task runner for Python3 that lets you automate tasks.
| It's inspired by `gulp.js`_.

| Pylp use a syntax similar to Gulp, making this task runner easy to
  learn and simple to use.
| Task process is completely asynchronous thanks to ``asyncio`` module,
  which provides a fast execution.


Documentation
=============

| Check out the `documentation`_ for a Getting started guide, API docs
  or
| making a plugin.


Sample ``pylpfile.py``
======================

This file is an example of what you can do with Pylp.

.. code:: python

    import pylp
    from pylpconcat import concat

    # Concat all js files from 'src' folder
    pylp.task('js', lambda:
        pylp.src('src/**/*.js')
          .pipe(concat('all.min.js'))
          .pipe(pylp.dest('build/js'))
    )

    # The default task (called when you run 'pylp' from cli)
    pylp.task('default', ['js'])


.. _gulp.js: https://gulpjs.com
.. _documentation: https://github.com/pylp/pylp/tree/master/docs